"""
PySide2 stub files generated by **IceSpringPySideStubs**

Home page: https://github.com/baijifeilong/IceSpringPySideStubs

Generated by BaiJiFeiLong@gmail.com

Licence: GPL-3
"""
import typing
import PySide2
import PySide2.QtCore

bytes = str


class QReadLocker(object):
    """
    **Detailed Description**

    The purpose of QReadLocker (and **QWriteLocker** ) is to simplify **QReadWriteLock**  locking and unlocking. Locking and unlocking statements or in exception handling code is error-prone and difficult to debug. QReadLocker can be used in such situations to ensure that the state of the lock is always well-defined.

    Here's an example that uses QReadLocker to lock and unlock a read-write lock for reading:

    **QReadWriteLock**  lock;

        **QByteArray**  readData()
        {
            **QReadLocker**  locker(&lock);
            ...
            return data;
        }

    It is equivalent to the following code:

    **QReadWriteLock**  lock;

        **QByteArray**  readData()
        {
            lock.lockForRead();
            ...
            lock.unlock();
            return data;
        }

    The **QMutexLocker**  documentation shows examples where the use of a locker object greatly simplifies programming.

    **See also** **QWriteLocker**  and **QReadWriteLock** .
    """

    def __init__(self, readWriteLock: PySide2.QtCore.QReadWriteLock) -> None:
        """
        **QReadLocker::QReadLocker(QReadWriteLock * lock )**

        Constructs a QReadLocker and locks **lock** for reading. The lock will be unlocked when the QReadLocker is destroyed. If `lock` is zero, QReadLocker does nothing.

        **See also** **QReadWriteLock::lockForRead** ().
        """
        ...

    def __enter__(self) -> None:
        ...

    def __exit__(self, arg__1: object, arg__2: object, arg__3: object) -> None:
        ...

    def readWriteLock(self) -> PySide2.QtCore.QReadWriteLock:
        """
        **QReadWriteLock *QReadLocker::readWriteLock() const**

        Returns a pointer to the read-write lock that was passed to the constructor.
        """
        ...

    def relock(self) -> None:
        """
        **void QReadLocker::relock()**

        Relocks an unlocked lock.

        **See also** **unlock** ().
        """
        ...

    def unlock(self) -> None:
        """
        **void QReadLocker::unlock()**

        Unlocks the lock associated with this locker.

        **See also** **QReadWriteLock::unlock** ().
        """
        ...
